
# 'iso_639_1', 'language_name'
LANGUAGES = (('ab', 'Abkhazian'), ('aa', 'Afar'), ('af', 'Afrikaans'), ('ak', 'Akan'),
             ('sq', 'Albanian'), ('am', 'Amharic'), ('ar', 'Arabic'), ('an', 'Aragonese'), ('hy', 'Armenian'),
             ('as', 'Assamese'), ('av', 'Avaric'), ('ae', 'Avestan'), ('ay', 'Aymara'), ('az', 'Azerbaijani'),
             ('bm', 'Bambara'), ('ba', 'Bashkir'), ('eu', 'Basque'), ('be', 'Belarusian'), ('bn', 'Bengali'),
             ('bh', 'Bihari languages'), ('bi', 'Bislama'), ('bs', 'Bosnian'), ('br', 'Breton'), ('bg', 'Bulgarian'),
             ('my', 'Burmese'), ('ca', 'Catalan, Valencian'), ('ch', 'Chamorro'), ('ce', 'Chechen'),
             ('ny', 'Chichewa, Chewa, Nyanja'), ('zh', 'Chinese'), ('cv', 'Chuvash'), ('kw', 'Cornish'),
             ('co', 'Corsican'), ('cr', 'Cree'), ('hr', 'Croatian'), ('cs', 'Czech'), ('da', 'Danish'),
             ('dv', 'Divehi, Dhivehi, Maldivian'), ('nl', 'Dutch, Flemish'), ('dz', 'Dzongkha'), ('en', 'English'),
             ('eo', 'Esperanto'), ('et', 'Estonian'), ('ee', 'Ewe'), ('fo', 'Faroese'), ('fj', 'Fijian'),
             ('fi', 'Finnish'), ('fr', 'French'), ('ff', 'Fulah'), ('gl', 'Galician'), ('ka', 'Georgian'),
             ('de', 'German'), ('el', 'Greek, Modern (1453–)'), ('gn', 'Guarani'), ('gu', 'Gujarati'),
             ('ht', 'Haitian, Haitian Creole'), ('ha', 'Hausa'), ('he', 'Hebrew'), ('hz', 'Herero'), ('hi', 'Hindi'),
             ('ho', 'Hiri Motu'), ('hu', 'Hungarian'),
             ('ia', 'Interlingua (International Auxiliary Language Association)'), ('id', 'Indonesian'),
             ('ie', 'Interlingue, Occidental'), ('ga', 'Irish'), ('ig', 'Igbo'), ('ik', 'Inupiaq'), ('io', 'Ido'),
             ('is', 'Icelandic'), ('it', 'Italian'), ('iu', 'Inuktitut'), ('ja', 'Japanese'), ('jv', 'Javanese'),
             ('kl', 'Kalaallisut, Greenlandic'), ('kn', 'Kannada'), ('kr', 'Kanuri'), ('ks', 'Kashmiri'),
             ('kk', 'Kazakh'), ('km', 'Central Khmer'), ('ki', 'Kikuyu, Gikuyu'), ('rw', 'Kinyarwanda'),
             ('ky', 'Kirghiz, Kyrgyz'), ('kv', 'Komi'), ('kg', 'Kongo'), ('ko', 'Korean'), ('ku', 'Kurdish'),
             ('kj', 'Kuanyama, Kwanyama'), ('la', 'Latin'), ('lb', 'Luxembourgish, Letzeburgesch'), ('lg', 'Ganda'),
             ('li', 'Limburgan, Limburger, Limburgish'), ('ln', 'Lingala'), ('lo', 'Lao'), ('lt', 'Lithuanian'),
             ('lu', 'Luba-Katanga'), ('lv', 'Latvian'), ('gv', 'Manx'), ('mk', 'Macedonian'), ('mg', 'Malagasy'),
             ('ms', 'Malay'), ('ml', 'Malayalam'), ('mt', 'Maltese'), ('mi', 'Maori'), ('mr', 'Marathi'),
             ('mh', 'Marshallese'), ('mn', 'Mongolian'), ('na', 'Nauru'), ('nv', 'Navajo, Navaho'),
             ('nd', 'North Ndebele'), ('ne', 'Nepali'), ('ng', 'Ndonga'), ('nb', 'Norwegian Bokmål'),
             ('nn', 'Norwegian Nynorsk'), ('no', 'Norwegian'), ('ii', 'Sichuan Yi, Nuosu'), ('nr', 'South Ndebele'),
             ('oc', 'Occitan'), ('oj', 'Ojibwa'),
             ('cu', 'Church Slavic, Old Slavonic, Church Slavonic, Old Bulgarian, Old Church Slavonic'),
             ('om', 'Oromo'), ('or', 'Oriya'), ('os', 'Ossetian, Ossetic'), ('pa', 'Punjabi, Panjabi'), ('pi', 'Pali'),
             ('fa', 'Persian'), ('pl', 'Polish'), ('ps', 'Pashto, Pushto'), ('pt', 'Portuguese'), ('qu', 'Quechua'),
             ('rm', 'Romansh'), ('rn', 'Rundi'), ('ro', 'Romanian, Moldavian, Moldovan'), ('ru', 'Russian'),
             ('sa', 'Sanskrit'), ('sc', 'Sardinian'), ('sd', 'Sindhi'), ('se', 'Northern Sami'), ('sm', 'Samoan'),
             ('sg', 'Sango'), ('sr', 'Serbian'), ('gd', 'Gaelic, Scottish Gaelic'), ('sn', 'Shona'),
             ('si', 'Sinhala, Sinhalese'), ('sk', 'Slovak'), ('sl', 'Slovenian'), ('so', 'Somali'),
             ('st', 'Southern Sotho'), ('es', 'Spanish, Castilian'), ('su', 'Sundanese'), ('sw', 'Swahili'),
             ('ss', 'Swati'), ('sv', 'Swedish'), ('ta', 'Tamil'), ('te', 'Telugu'), ('tg', 'Tajik'), ('th', 'Thai'),
             ('ti', 'Tigrinya'), ('bo', 'Tibetan'), ('tk', 'Turkmen'), ('tl', 'Tagalog'), ('tn', 'Tswana'),
             ('to', 'Tonga (Tonga Islands)'), ('tr', 'Turkish'), ('ts', 'Tsonga'), ('tt', 'Tatar'), ('tw', 'Twi'),
             ('ty', 'Tahitian'), ('ug', 'Uighur, Uyghur'), ('uk', 'Ukrainian'), ('ur', 'Urdu'), ('uz', 'Uzbek'),
             ('ve', 'Venda'), ('vi', 'Vietnamese'), ('vo', 'Volapük'), ('wa', 'Walloon'), ('cy', 'Welsh'),
             ('wo', 'Wolof'), ('fy', 'Western Frisian'), ('xh', 'Xhosa'), ('yi', 'Yiddish'), ('yo', 'Yoruba'),
             ('za', 'Zhuang, Chuang'))

# 'iso _639_1', 'native_name', 'language_name'
# LANGUAGES = (
#     ('ab', 'аҧсуа бызшәа, аҧсшәа', 'Abkhazian'),
#     ('aa', 'Afaraf', 'Afar'),
#     ('af', 'Afrikaans', 'Afrikaans'), ('ak', 'Akan', 'Akan'), ('sq', 'Shqip', 'Albanian'), ('am', 'አማርኛ', 'Amharic'),
#     ('ar', 'العربية', 'Arabic'), ('an', 'aragonés', 'Aragonese'), ('hy', 'Հայերեն', 'Armenian'),
#     ('as', 'অসমীয়া', 'Assamese'), ('av', 'авар мацӀ, магӀарул мацӀ', 'Avaric'), ('ae', 'avesta', 'Avestan'),
#     ('ay', 'aymar aru', 'Aymara'), ('az', 'azərbaycan dili', 'Azerbaijani'), ('bm', 'bamanankan', 'Bambara'),
#     ('ba', 'башҡорт теле', 'Bashkir'), ('eu', 'euskara, euskera', 'Basque'), ('be', 'беларуская мова', 'Belarusian'),
#     ('bn', 'বাংলা', 'Bengali'), ('bh', 'भोजपुरी', 'Bihari languages'), ('bi', 'Bislama', 'Bislama'),
#     ('bs', 'bosanski jezik', 'Bosnian'), ('br', 'brezhoneg', 'Breton'), ('bg', 'български език', 'Bulgarian'),
#     ('my', 'ဗမာစာ', 'Burmese'), ('ca', 'català, valencià', 'Catalan, Valencian'), ('ch', 'Chamoru', 'Chamorro'),
#     ('ce', 'нохчийн мотт', 'Chechen'), ('ny', 'chiCheŵa, chinyanja', 'Chichewa, Chewa, Nyanja'),
#     ('zh', '中文 (Zhōngwén), 汉语, 漢語', 'Chinese'), ('cv', 'чӑваш чӗлхи', 'Chuvash'), ('kw', 'Kernewek', 'Cornish'),
#     ('co', 'corsu, lingua corsa', 'Corsican'), ('cr', 'ᓀᐦᐃᔭᐍᐏᐣ', 'Cree'), ('hr', 'hrvatski jezik', 'Croatian'),
#     ('cs', 'čeština, český jazyk', 'Czech'), ('da', 'dansk', 'Danish'),
#     ('dv', 'ދިވެހި', 'Divehi, Dhivehi, Maldivian'),
#     ('nl', 'Nederlands, Vlaams', 'Dutch, Flemish'), ('dz', 'རྫོང་ཁ', 'Dzongkha'), ('en', 'English', 'English'),
#     ('eo', 'Esperanto', 'Esperanto'), ('et', 'eesti, eesti keel', 'Estonian'), ('ee', 'Eʋegbe', 'Ewe'),
#     ('fo', 'føroyskt', 'Faroese'), ('fj', 'vosa Vakaviti', 'Fijian'), ('fi', 'suomi, suomen kieli', 'Finnish'),
#     ('fr', 'français, langue française', 'French'), ('ff', 'Fulfulde, Pulaar, Pular', 'Fulah'),
#     ('gl', 'Galego', 'Galician'), ('ka', 'ქართული', 'Georgian'), ('de', 'Deutsch', 'German'),
#     ('el', 'ελληνικά', 'Greek, Modern (1453–)'), ('gn', 'Avañe\'ẽ', 'Guarani'), ('gu', 'ગુજરાતી', 'Gujarati'),
#     ('ht', 'Kreyòl ayisyen', 'Haitian, Haitian Creole'), ('ha', '(Hausa) هَوُسَ', 'Hausa'), ('he', 'עברית', 'Hebrew'),
#     ('hz', 'Otjiherero', 'Herero'), ('hi', 'हिन्दी, हिंदी', 'Hindi'), ('ho', 'Hiri Motu', 'Hiri Motu'),
#     ('hu', 'magyar', 'Hungarian'),
#     ('ia', 'Interlingua', 'Interlingua (International Auxiliary Language Association)'),
#     ('id', 'Bahasa Indonesia', 'Indonesian'),
#     ('ie', '(originally:) Occidental, (after WWII:) Interlingue', 'Interlingue, Occidental'),
#     ('ga', 'Gaeilge', 'Irish'),
#     ('ig', 'Asụsụ Igbo', 'Igbo'), ('ik', 'Iñupiaq, Iñupiatun', 'Inupiaq'), ('io', 'Ido', 'Ido'),
#     ('is', 'Íslenska', 'Icelandic'), ('it', 'Italiano', 'Italian'), ('iu', 'ᐃᓄᒃᑎᑐᑦ', 'Inuktitut'),
#     ('ja', '日本語 (にほんご)', 'Japanese'), ('jv', 'ꦧꦱꦗꦮ, Basa Jawa', 'Javanese'),
#     ('kl', 'kalaallisut, kalaallit oqaasii', 'Kalaallisut, Greenlandic'), ('kn', 'ಕನ್ನಡ', 'Kannada'),
#     ('kr', 'Kanuri', 'Kanuri'), ('ks', 'कश्मीरी, كشميري', 'Kashmiri'), ('kk', 'қазақ тілі', 'Kazakh'),
#     ('km', 'ខ្មែរ, ខេមរភាសា, ភាសាខ្មែរ', 'Central Khmer'), ('ki', 'Gĩkũyũ', 'Kikuyu, Gikuyu'),
#     ('rw', 'Ikinyarwanda', 'Kinyarwanda'), ('ky', 'Кыргызча, Кыргыз тили', 'Kirghiz, Kyrgyz'),
#     ('kv', 'коми кыв', 'Komi'),
#     ('kg', 'Kikongo', 'Kongo'), ('ko', '한국어', 'Korean'), ('ku', 'Kurdî, کوردی', 'Kurdish'),
#     ('kj', 'Kuanyama', 'Kuanyama, Kwanyama'), ('la', 'latine, lingua latina', 'Latin'),
#     ('lb', 'Lëtzebuergesch', 'Luxembourgish, Letzeburgesch'), ('lg', 'Luganda', 'Ganda'),
#     ('li', 'Limburgs', 'Limburgan, Limburger, Limburgish'), ('ln', 'Lingála', 'Lingala'), ('lo', 'ພາສາລາວ', 'Lao'),
#     ('lt', 'lietuvių kalba', 'Lithuanian'), ('lu', 'Kiluba', 'Luba-Katanga'), ('lv', 'latviešu valoda', 'Latvian'),
#     ('gv', 'Gaelg, Gailck', 'Manx'), ('mk', 'македонски јазик', 'Macedonian'), ('mg', 'fiteny malagasy', 'Malagasy'),
#     ('ms', 'Bahasa Melayu, بهاس ملايو', 'Malay'), ('ml', 'മലയാളം', 'Malayalam'), ('mt', 'Malti', 'Maltese'),
#     ('mi', 'te reo Māori', 'Maori'), ('mr', 'मराठी', 'Marathi'), ('mh', 'Kajin M̧ajeļ', 'Marshallese'),
#     ('mn', 'Монгол хэл', 'Mongolian'), ('na', 'Dorerin Naoero', 'Nauru'), ('nv', 'Diné bizaad', 'Navajo, Navaho'),
#     ('nd', 'isiNdebele', 'North Ndebele'), ('ne', 'नेपाली', 'Nepali'), ('ng', 'Owambo', 'Ndonga'),
#     ('nb', 'Norsk Bokmål', 'Norwegian Bokmål'), ('nn', 'Norsk Nynorsk', 'Norwegian Nynorsk'),
#     ('no', 'Norsk', 'Norwegian'),
#     ('ii', 'ꆈꌠ꒿ Nuosuhxop', 'Sichuan Yi, Nuosu'), ('nr', 'isiNdebele', 'South Ndebele'),
#     ('oc', 'occitan, lenga d\'òc', 'Occitan'), ('oj', 'ᐊᓂᔑᓈᐯᒧᐎᓐ', 'Ojibwa'),
#     ('cu', 'ѩзыкъ словѣньскъ', 'Church Slavic, Old Slavonic, Church Slavonic, Old Bulgarian, Old Church Slavonic'),
#     ('om', 'Afaan Oromoo', 'Oromo'), ('or', 'ଓଡ଼ିଆ', 'Oriya'), ('os', 'ирон æвзаг', 'Ossetian, Ossetic'),
#     ('pa', 'ਪੰਜਾਬੀ, پنجابی', 'Punjabi, Panjabi'), ('pi', 'पालि, पाळि', 'Pali'), ('fa', 'فارسی', 'Persian'),
#     ('pl', 'język polski, polszczyzna', 'Polish'), ('ps', 'پښتو', 'Pashto, Pushto'),
#     ('pt', 'Português', 'Portuguese'),
#     ('qu', 'Runa Simi, Kichwa', 'Quechua'), ('rm', 'Rumantsch Grischun', 'Romansh'), ('rn', 'Ikirundi', 'Rundi'),
#     ('ro', 'Română', 'Romanian, Moldavian, Moldovan'), ('ru', 'русский', 'Russian'), ('sa', 'संस्कृतम्', 'Sanskrit'),
#     ('sc', 'sardu', 'Sardinian'), ('sd', 'सिन्धी, سنڌي، سندھی', 'Sindhi'), ('se', 'Davvisámegiella', 'Northern Sami'),
#     ('sm', 'gagana fa\'a Samoa', 'Samoan'), ('sg', 'yângâ tî sängö', 'Sango'), ('sr', 'српски језик', 'Serbian'),
#     ('gd', 'Gàidhlig', 'Gaelic, Scottish Gaelic'), ('sn', 'chiShona', 'Shona'), ('si', 'සිංහල', 'Sinhala, Sinhalese'),
#     ('sk', 'Slovenčina, Slovenský Jazyk', 'Slovak'), ('sl', 'Slovenski Jezik, Slovenščina', 'Slovenian'),
#     ('so', 'Soomaaliga, af Soomaali', 'Somali'), ('st', 'Sesotho', 'Southern Sotho'),
#     ('es', 'Español', 'Spanish, Castilian'), ('su', 'Basa Sunda', 'Sundanese'), ('sw', 'Kiswahili', 'Swahili'),
#     ('ss', 'SiSwati', 'Swati'), ('sv', 'Svenska', 'Swedish'), ('ta', 'தமிழ்', 'Tamil'), ('te', 'తెలుగు', 'Telugu'),
#     ('tg', 'тоҷикӣ, toçikī, تاجیکی', 'Tajik'), ('th', 'ไทย', 'Thai'), ('ti', 'ትግርኛ', 'Tigrinya'),
#     ('bo', 'བོད་ཡིག', 'Tibetan'), ('tk', 'Türkmen, Түркмен', 'Turkmen'), ('tl', 'Wikang Tagalog', 'Tagalog'),
#     ('tn', 'Setswana', 'Tswana'), ('to', 'Faka Tonga', 'Tonga (Tonga Islands)'), ('tr', 'Türkçe', 'Turkish'),
#     ('ts', 'Xitsonga', 'Tsonga'), ('tt', 'татар теле, tatar tele', 'Tatar'), ('tw', 'Twi', 'Twi'),
#     ('ty', 'Reo Tahiti', 'Tahitian'), ('ug', 'ئۇيغۇرچە, Uyghurche', 'Uighur, Uyghur'),
#     ('uk', 'Українська', 'Ukrainian'),
#     ('ur', 'اردو', 'Urdu'), ('uz', 'Oʻzbek, Ўзбек, أۇزبېك', 'Uzbek'), ('ve', 'Tshivenḓa', 'Venda'),
#     ('vi', 'Tiếng Việt', 'Vietnamese'), ('vo', 'Volapük', 'Volapük'), ('wa', 'Walon', 'Walloon'),
#     ('cy', 'Cymraeg', 'Welsh'), ('wo', 'Wollof', 'Wolof'), ('fy', 'Frysk', 'Western Frisian'),
#     ('xh', 'isiXhosa', 'Xhosa'),
#     ('yi', 'ייִדיש', 'Yiddish'), ('yo', 'Yorùbá', 'Yoruba'), ('za', 'Saɯ cueŋƅ, Saw cuengh', 'Zhuang, Chuang'))
